@@ -1,9 +1,9 @@
 import json
 
-from .common_service import BaseEMCRestCaseAdmin
+from .common_service import BaseOnaroRestCaseAdmin
 
 
-class CRMLeadServiceRestCase(BaseEMCRestCaseAdmin):
+class CRMLeadServiceRestCase(BaseOnaroRestCaseAdmin):
 
     def test_route_right_create(self):
         url = "/api/crm-lead"
@@ -13,26 +13,14 @@ class CRMLeadServiceRestCase(BaseEMCRestCaseAdmin):
             "birth_date": "25/8/1996",
             "phone": "641708221",
             "email_from": "1k3b85mo0@hotmail.com",
-            "street": {
-                "street": "Carrer del Rec",
-                "street2": "123",
-                "zip_code": "08000",
-                "city": "Barcelona",
-                "country": "ES",
-                "state": "B"
-            },
-            "invoice_address": {
-                "street": "Carrer del Bruc",
-                "street2": "12",
-                "zip_code": "08001",
-                "city": "Barcelona",
-                "country": "ES",
-                "state": "B"
-            },
-            "portability_number": {"687608770"},
+            "street": "Carrer del Rec",
+            "invoice_address": "Carrer del Bruc",
+            "portability_number": "687608770",
             "iban": "ES6621000418401234567891",
-            "language": "EU",
+            "language": "es",
             "policy_accepted": True,
+            "tag_ids": [1,2],
+            "description": "Crm lead line notes",
         }
 
         response = self.http_post(url, data=data)
@@ -49,8 +37,13 @@ class CRMLeadServiceRestCase(BaseEMCRestCaseAdmin):
         self.assertEquals(crm_lead.phone, data["phone"])
         self.assertEquals(crm_lead.email_from, data["email_from"])
         self.assertEquals(crm_lead.street, data["street"])
+        self.assertEquals(crm_lead.zip, '20560')
+        self.assertEquals(crm_lead.city, 'Oñati')
+        self.assertEquals(crm_lead.state_id, self.ref("base.state_es_ss").id)
         self.assertEquals(crm_lead.invoice_address, data["invoice_address"])
         self.assertEquals(crm_lead.portability_number, data["portability_number"])
         self.assertEquals(crm_lead.iban, data["iban"])
         self.assertEquals(crm_lead.language, data["language"])
         self.assertEquals(crm_lead.policy_accepted, data["policy_accepted"])
+        self.assertEquals(crm_lead.tag_ids.ids, data["tag_ids"])
+        self.assertEquals(crm_lead.description, data["description"])
